@@ -1,14 +1,11 @@
-/* dribble.h -- Functions and vars declared in dribble.c. */
+/* dribble.h -- Functions and vars declared in dribble.c.
 
-/* This file is part of GNU Info, a program for reading online documentation
-   stored in Info format.
+   Copyright 1993-2022 Free Software Foundation, Inc.
 
-   Copyright (C) 1993, 2004 Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,10 +13,9 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-   Written by Brian Fox (bfox@ai.mit.edu). */
+   Originally written by Brian Fox. */
 
 #if !defined (_DRIBBLE_H_)
 #define _DRIBBLE_H_
