@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright (C) 2014 Free Software Foundation, Inc.
+# Copyright (C) 2014-2019 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,5 +19,5 @@ srcdir=${srcdir:-.}
 
 # Load a node in loaded file using --node. 
 
-$GINFO --output - --file file-menu --node Unreachable \
+$ginfo --output - --file file-menu --node Unreachable \
   | grep 'not linked to elsewhere'
