@@ -1,22 +1,26 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'unknown_value'} = {
   'contents' => [
     {
-      'cmdname' => 'value',
-      'contents' => [],
-      'parent' => {},
-      'type' => 'unknown'
+      'contents' => [
+        {
+          'cmdname' => 'value',
+          'extra' => {
+            'flag' => 'unknown'
+          }
+        }
+      ],
+      'type' => 'before_node_section'
     }
   ],
-  'type' => 'text_root'
+  'type' => 'document_root'
 };
-$result_trees{'unknown_value'}{'contents'}[0]{'parent'} = $result_trees{'unknown_value'};
 
 $result_texis{'unknown_value'} = '@value{unknown}';
 
@@ -25,7 +29,7 @@ $result_texts{'unknown_value'} = '';
 
 $result_errors{'unknown_value'} = [
   {
-    'error_line' => ':1: warning: undefined flag: unknown
+    'error_line' => 'warning: undefined flag: unknown
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -36,8 +40,11 @@ $result_errors{'unknown_value'} = [
 ];
 
 
+$result_floats{'unknown_value'} = {};
 
-$result_converted{'plaintext'}->{'unknown_value'} = '{No value for \'unknown\'}
+
+
+$result_converted{'plaintext'}->{'unknown_value'} = '{No value for ‘unknown’}
 ';
 
 
@@ -49,4 +56,7 @@ $result_converted{'xml'}->{'unknown_value'} = '';
 
 $result_converted{'docbook'}->{'unknown_value'} = '';
 
+
+$result_converted{'latex_text'}->{'unknown_value'} = '\\{No value for `unknown\'\\}';
+
 1;
