@@ -1,41 +1,38 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'double_include'} = {
   'contents' => [
-    {
-      'parent' => {},
-      'text' => '
-',
-      'type' => 'empty_line'
-    },
     {
       'contents' => [
         {
-          'parent' => {},
-          'text' => 'In included file.
-'
+          'text' => '
+',
+          'type' => 'empty_line'
         },
         {
-          'parent' => {},
-          'text' => 'In included file.
+          'contents' => [
+            {
+              'text' => 'In included file.
 '
+            },
+            {
+              'text' => 'In included file.
+'
+            }
+          ],
+          'type' => 'paragraph'
         }
       ],
-      'parent' => {},
-      'type' => 'paragraph'
+      'type' => 'before_node_section'
     }
   ],
-  'type' => 'text_root'
+  'type' => 'document_root'
 };
-$result_trees{'double_include'}{'contents'}[0]{'parent'} = $result_trees{'double_include'};
-$result_trees{'double_include'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'double_include'}{'contents'}[1];
-$result_trees{'double_include'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'double_include'}{'contents'}[1];
-$result_trees{'double_include'}{'contents'}[1]{'parent'} = $result_trees{'double_include'};
 
 $result_texis{'double_include'} = '
 In included file.
@@ -50,7 +47,7 @@ In included file.
 
 $result_errors{'double_include'} = [
   {
-    'error_line' => ':2: warning: @include should only appear at the beginning of a line
+    'error_line' => 'warning: @include should only appear at the beginning of a line
 ',
     'file_name' => '',
     'line_nr' => 2,
@@ -59,7 +56,7 @@ $result_errors{'double_include'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => ':2: warning: @include should not appear in @include
+    'error_line' => 'warning: @include should not appear in @include
 ',
     'file_name' => '',
     'line_nr' => 2,
